@@ -1,10 +1,10 @@
 if __name__ == '__main__':
-    from sklearn.datasets import load_boston
+    from sklearn.datasets import load_diabetes
     import pandas as pd
     from yikit.feature_selection import BorutaPy
     from sklearn.ensemble import RandomForestRegressor
 
-    boston = load_boston()
-    X = pd.DataFrame(boston['data'], columns = boston['feature_names'])
-    y = pd.Series(boston['target'], name = 'PRICE')
+    diabetes = load_diabetes()
+    X = pd.DataFrame(diabetes['data'], columns = diabetes['feature_names'])
+    y = pd.Series(diabetes['target'])
     print(BorutaPy(RandomForestRegressor(n_jobs=-1, random_state=334), random_state=334).fit(X, y).support_)
\ No newline at end of file
