@@ -23,6 +23,9 @@ from sklearn.utils.validation import check_is_fitted
 from scipy.stats import pearsonr
 import pandas as pd
 import numpy as np
+import warnings
+
+from typing import Any
 
 from yikit.tools import is_notebook
 if is_notebook():
@@ -35,7 +38,7 @@ else:
 
 
 class FilterSelector(SelectorMixin, BaseEstimator):
-    def __init__(self, r = 0.9, alpha = 0.05):
+    def __init__(self, r = 0.9, alpha = 0.05, verbose = True):
         """Filter method (feature selection)
 
         Parameters
@@ -44,9 +47,25 @@ class FilterSelector(SelectorMixin, BaseEstimator):
             相関係数を高いとする閾値．これより高いと相関が高いとして，削除対象とする．, by default 0.9
         alpha : float, optional
             有意水準．これよりp値が低い時，相関係数の値が信頼に足ると判断．特別な理由がない限りはこれを変えないのがベター．, by default 0.05
+        verbose : bool, optional
+            バッチ処理中に進捗を表示するかどうか．, by default True
         """
         self.r = r
         self.alpha = alpha
+        self.verbose = verbose
+
+        if verbose > 0:
+            try:
+                import tqdm
+            except ImportError as e:
+                mess = '{}\nIf exists, a progress bar can be displayed.'.format(e)
+                warnings.warn(mess)
+                self._flag_tqdm = False
+            else:
+                self._flag_tqdm = True
+        else:
+            self._flag_tqdm = False
+
 
     def fit(self, X, y = None):
         """fit
@@ -59,7 +78,7 @@ class FilterSelector(SelectorMixin, BaseEstimator):
             不要．, by default None
         """
         # checkかつnp.ndarrayに変換される．
-        X = check_array(X)
+        X:np.ndarray = check_array(X)
 
         # よくつかうので列数を変数で保存
         n_features = X.shape[1]
@@ -71,7 +90,16 @@ class FilterSelector(SelectorMixin, BaseEstimator):
         # i番目の要素は，i番目と相関係数がcorr以上かつp値が有意水準alpha未満のものの集合．これの鋳型を作成
         pair = [set() for _ in range(n_features)]
 
-        for i in range(n_features):
+        if self.verbose > 0 and self._flag_tqdm:
+            if is_notebook():
+                from tqdm.notebook import trange
+            else:
+                from tqdm import trange
+            _range = trange(n_features, desc = 'correlation')
+        else:
+            _range = range(n_features)
+        
+        for i in _range:
             for j in range(i, n_features):
                 if i == j:  # 一緒の時はそもそも相関係数1, p値0は自明なので例外処理
                     self.corr_[i, i] = [1.0, 0.0]
@@ -84,7 +112,7 @@ class FilterSelector(SelectorMixin, BaseEstimator):
                         pair[j].add(i)
 
         # 何個相関係数が高い係数が存在するのかの値を求める．
-        def _delete_recursive(pair, boolean = np.ones(n_features, dtype = bool)):
+        def _delete_recursive(pair, boolean = np.ones(n_features, dtype = bool))->np.ndarray:
             # 相関係数が高いものがいくつあるのかのnp.ndarrayを作成
             order_pair = np.array([len(s) for s in pair])
 
@@ -107,15 +135,15 @@ class FilterSelector(SelectorMixin, BaseEstimator):
 
         return self
 
-    def _get_support_mask(self):
+    def _get_support_mask(self)->np.ndarray:
         check_is_fitted(self, 'support_')
         return self.support_
 
 if __name__ == '__main__':
     from pdb import set_trace
-    from sklearn.datasets import load_boston
+    from sklearn.datasets import load_diabetes
 
-    data = load_boston()
+    data = load_diabetes()
     X = pd.DataFrame(data.data, columns = data.feature_names)
     # X = pd.concat([X, pd.Series(np.ones(X.shape[0]))], axis = 1)
 
